@@ -3,15 +3,14 @@ use warnings;
 use 5.008;
 
 package DBIx::Locker;
-our $VERSION = '0.092650';
-
+our $VERSION = '0.100110';
 # ABSTRACT: locks for db resources that might not be totally insane
 
 use Carp ();
 use DBI;
 use Data::GUID ();
 use DBIx::Locker::Lock;
-use JSON::XS ();
+use JSON 2 ();
 use Sys::Hostname ();
 
 
@@ -143,7 +142,6 @@ sub purge_expired_locks {
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -152,7 +150,7 @@ DBIx::Locker - locks for db resources that might not be totally insane
 
 =head1 VERSION
 
-version 0.092650
+version 0.100110
 
 =head1 DESCRIPTION
 
@@ -220,11 +218,10 @@ This method deletes expired semaphores.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Ricardo SIGNES.
+This software is copyright (c) 2010 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
